# GPF简介

gpflib库提供了一种**基于网格的自然语言结构分析框架（Grid based Parsing Framework，GPF）**。该框架中，语言结构分析被泛化为识别语言单元和建立语言单元之间的关系、为语言单元和关系赋予属性的过程。通过gpflib，用户可以实现可控的自然语言结构计算。

GPF具有以下特点：

1. 利用网格结构分析语言单元和关系，通过键值方式对其属性进行描述和计算；
2. 采用数据表表示不同类型的知识；
3. 借助有限状态自动机剖析语言的具体应用场景；
4. 定义了数据交换标准接口，可以利用深度学习方法的结果，在网格中进行融合计算。

GPF具有良好的包容性，该框架以符号计算为主导，由它接收输入、输出结果，具有更好的可控性、可扩展性和可解释性。


# 说明文档

GPF说明文档及使用示例： http://gpf.blcu.edu.cn.

# 参考书目

[《自然语言结构计算——GPF结构分析框架》](https://item.jd.com/13574545.html)——荀恩东著

# 引用

如果在工作中使用了 GPF，您可以引用：

> 荀恩东.自然语言结构计算——GPF结构分析框架[M].北京:人民邮电出版社.2022
